@@ -1,14 +1,26 @@
 # -*- coding: utf-8 -*-
+from django.test.utils import override_settings
+
 from allauth.socialaccount.providers.keycloak.provider import KeycloakProvider
-from allauth.socialaccount.tests import OAuth2TestsMixin
+from allauth.socialaccount.tests import OpenIDConnectTests
 from allauth.tests import MockedResponse, TestCase
 
 
-class KeycloakTests(OAuth2TestsMixin, TestCase):
+@override_settings(
+    SOCIALACCOUNT_PROVIDERS={
+        KeycloakProvider.id: dict(
+            KEYCLOAK_URL="https://keycloak.unittest.example",
+            KEYCLOAK_REALM="unittest",
+        )
+    }
+)
+class KeycloakTests(OpenIDConnectTests, TestCase):
     provider_id = KeycloakProvider.id
 
     def get_mocked_response(self):
-        return MockedResponse(200, """
+        return MockedResponse(
+            200,
+            """
             {
                 "picture": "https://secure.gravatar.com/avatar/123",
                 "email": "mr.bob@your.Keycloak.server.example.com",
@@ -17,4 +29,5 @@ class KeycloakTests(OAuth2TestsMixin, TestCase):
                 "identities": [],
                 "name": "Mr Bob"
             }
-        """)
+        """,
+        )
